from datetime import datetime
from typing import Optional
from pydantic import BaseModel, HttpUrl

class WebsiteCreate(BaseModel):
    url: HttpUrl
    name: str
    check_interval_minutes: Optional[int] = 60

class WebsiteUpdate(BaseModel):
    name: Optional[str] = None
    check_interval_minutes: Optional[int] = None
    is_active: Optional[bool] = None

class WebsiteResponse(BaseModel):
    id: int
    url: str
    name: str
    last_checked: Optional[datetime]
    is_active: bool
    check_interval_minutes: int
    created_at: datetime
    updated_at: datetime

    class Config:
        from_attributes = True

class AlertResponse(BaseModel):
    id: int
    website_id: int
    alert_message: str
    detected_at: datetime
    is_read: bool

    class Config:
        from_attributes = True